#!/usr/bin/env python
# Copyright (c) 2002,2003 by Intevation GmbH
# Authors:
# Frank Koormann <frank.koormann@intevation.de>
#
# This program is free software under the GPL (>=v2)
# Read the file COPYING for details.

version__ = "$Revision: 1.3 $"
# $Source: /greaterrepository/greater-pre-processing/insert-stretch_att.py,v $
# $Id: insert-stretch_att.py,v 1.3 2003/05/20 09:34:04 frank Exp $

import os
import sys

from string import atof

def usage(name):
    """Print usage information."""

    print "USAGE: %s [stretch attribute table] [catchment id]" % name
    print
 
def convert_disch( fname, catch_id ):
    """Convert GREAT-ER I stretch.att to GREAT-ER II STRETCH_TAB inserts.
    """

    try:
        disch_att = open(fname, 'r').readlines()
    except:
        print "Error: Could not find or open file '" + fname + "'"
        usage(sys.argv[0])
        return 1
    else:
        print "SPOOL %s-insert_stretch.log" % fname
        for line in disch_att:
            if line[0] == '#':
                continue
            d = line.split(',')
            name = d[15].rstrip().replace("'","''")
            print ("INSERT INTO stretch_tab VALUES (%s, %s, %s, %s, %s, %s, %s,\
                '%s', '%s', '%e;%e', '%s', '%e;%e', '%s', '%e', '%e;%e', '%s');"
                    % (d[0], catch_id, d[7], d[3], d[4], d[5], d[6],
                       name, d[1], 
                atof(d[8]),atof(LogNorm_FivePercentileToStddev((d[8], d[9]))),
                        "2",
                atof(d[10]),atof(LogNorm_FivePercentileToStddev((d[10],d[11]))),
                        "2",
                        atof(d[12]),
                atof(d[13]),atof(LogNorm_FivePercentileToStddev((d[13],d[14]))),
                        "2",
                  ))
        print "COMMIT;"
        print "SPOOL OFF"


def LogNorm_FivePercentileToStddev(descriptives):
    """Derive stddev for log-normal distribution from 5 percentile and mean."""

    from math import sqrt, log, exp

    # P( Z >= z ) = 0.05, standard-normal distribution
    z = -1.6449

    if len(descriptives) == 2:
        mean    = float(descriptives[0])
        perfive = float(descriptives[1])
        if ( mean == 0.0 or perfive == 0.0 ):
            return 0.0
        else:
            # Stddev of corresponding normal distribution
            sy = sqrt(z*z - 2 * log( perfive / mean )) + z

            # 
            sx = mean * sqrt( exp( sy*sy ) - 1 )
            
            return sx

    else:
        return 0.0
if __name__ == '__main__':
    import sys

    if len(sys.argv) == 3:
        convert_disch(sys.argv[1], sys.argv[2])
    else:
        usage(sys.argv[0])
