# Copyright (c) 2003 by Intevation GmbH
# Authors:
# Jan-Oliver Wagner <jan@intevation.de>
#
# This program is free software under the GPL (>=v2)
# Read the file COPYING coming with Thuban for details.

"""
Test the support methods

These tests test the methods in the support module.
"""

__version__ = "$Revision: 1.1 $"
# $Source: /greaterrepository/greater-pre-processing/test/test_support.py,v $
# $Id: test_support.py,v 1.1 2003/05/20 13:42:24 jan Exp $

import os, sys
import unittest

thisdir = os.path.dirname(__file__)
path = os.path.join(thisdir, os.pardir)
sys.path.insert(0, path)

import support

class SupportTest(unittest.TestCase):

    def test_check_for_circle(self):
        """test check for circles in topplogy"""
        eq = self.assertEquals

        # strechid, type, up1, up2, down1, down2
        # this river has a circle
        rivertable = [ \
            ( 342,  2, 344, 378, 486,   0 ),
            ( 344, -2, 468, 475, 342,   0 ),
            ( 378,  0,   0,   0, 342,   0 ),
            ( 468,  1, 481,   0, 475, 344 ),
            ( 475, -2, 468, 344,   0,   0 ),
            ( 480,  0,   0,   0, 481,   0 ),
            ( 481,  2, 480, 486, 468,   0 ),
            ( 486,  1, 342,   0, 481,   0 ) ]

        result = support.check_for_circle(rivertable)
        eq(isinstance(result, list), 1)
        eq(result, [468, 344, 342, 486, 481, 468])

        # strechid, type, up1, up2, down1, down2
        # this river has no circle
        rivertable = [ \
            ( 475,  0,   0,   0,   0,   0 ) ]

        result = support.check_for_circle(rivertable)
        eq(result, 0)

        # this table is corrupt
        rivertable = [ \
            ( 0,   0,   0,   0,   0 ) ]

        result = support.check_for_circle(rivertable)
        eq(result, None)

if __name__ == "__main__":
    unittest.main()
